import { __rest } from "tslib";
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import clsx from 'clsx';
import { forwardRef } from 'react';
import Button from '../Button';
import Card from '../Card';
import CardActions from '../CardActions';
import CardContent from '../CardContent';
import Typography from '../Typography';

/**
 * The Action Card component is an extended version of the `Card` component with an action button.
 *
 * Demos:
 *
 * - [Action Card (Oxygen UI)](https://wso2.github.io/oxygen-ui/react/?path=/docs/surfaces-action-card)
 *
 * API:
 *
 * - inherits [Card API](https://mui.com/material-ui/api/card/)
 *
 * @remarks
 * - ✨ This is a custom component that is not available in the Material-UI library.
 * - ✔️ Props of the [Paper](https://mui.com/material-ui/api/card/) component are also available.
 * - ✅ `component` prop is supported.
 * - ✅ The `ref` is forwarded to the root element.
 *
 * @template C - The type of the component.
 * @param props - The props for the ActionCard component.
 * @param ref - The ref to be forwarded to the Card component.
 * @returns The rendered ActionCard component.
 */
const ActionCard = forwardRef((_a, ref) => {
    var { className, image, title, description, actionText, onActionClick } = _a, rest = __rest(_a, ["className", "image", "title", "description", "actionText", "onActionClick"]);
    return (_jsxs(Card, Object.assign({ ref: ref, className: clsx(
        /* @deprecated Use the PascalCase classname instead. https://github.com/wso2/oxygen-ui/issues/274 */
        'oxygen-action-card', 'OxygenActionCard-root', className) }, rest, { children: [_jsxs(CardContent, { children: [image, _jsx(Typography, Object.assign({ variant: "subtitle1" }, { children: title })), _jsx(Typography, Object.assign({ variant: "body2" }, { children: description }))] }), _jsx(CardActions, { children: _jsx(Button, Object.assign({ onClick: onActionClick, variant: "contained" }, { children: actionText })) })] })));
});
export default ActionCard;
function addCSS(css){var head = document.getElementsByTagName('head')[0];var s = document.createElement('style');s.setAttribute('type', 'text/css');s.appendChild(document.createTextNode(css));head.appendChild(s);}
addCSS("/**\n * Copyright (c) 2023, WSO2 LLC. (https://www.wso2.com).\n *\n * WSO2 LLC. licenses this file to you under the Apache License,\n * Version 2.0 (the \"License\"); you may not use this file except\n * in compliance with the License.\n * You may obtain a copy of the License at\n *\n *     http://www.apache.org/licenses/LICENSE-2.0\n *\n * Unless required by applicable law or agreed to in writing,\n * software distributed under the License is distributed on an\n * \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n * KIND, either express or implied. See the License for the\n * specific language governing permissions and limitations\n * under the License.\n */\n.oxygen-action-card:hover {\n  border: 1px solid var(--oxygen-palette-primary-main);\n}");