/**
 * Copyright (c) 2023, WSO2 LLC. (https://www.wso2.com). All Rights Reserved.
 *
 * WSO2 LLC. licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
import type { AutocompleteProps as MuiAutocompleteProps } from '@mui/material/Autocomplete';
import type { ForwardRefExoticComponent } from 'react';
import type { ChipTypeMap } from '../Chip';

export type AutocompleteProps<T, Multiple extends boolean | undefined = boolean | undefined, DisableClearable extends boolean | undefined = boolean | undefined, FreeSolo extends boolean | undefined = boolean | undefined, ChipComponent extends React.ElementType = ChipTypeMap['defaultComponent']> = MuiAutocompleteProps<T, Multiple, DisableClearable, FreeSolo, ChipComponent>;
/**
 * The Autocomplete is a normal text input enhanced by a panel of suggested options.
 *
 * Demos:
 *
 * - [Autocomplete (Oxygen UI)](https://wso2.github.io/oxygen-ui/react/?path=/docs/inputs-autocomplete)
 * - [Autocomplete (MUI)](https://mui.com/material-ui/react-autocomplete/)
 *
 * API:
 *
 * - [Autocomplete API](https://mui.com/material-ui/api/autocomplete/)
 *
 * @remarks
 * - ✔️ Props of the native component are also available.
 * - ❌ `component` prop is not supported.
 * - ❌ The component cannot hold a `ref`.
 *
 * @param props - The props for the Accordion component.
 * @param ref - The ref to be forwarded to the MuiAccordion component.
 * @returns The rendered Accordion component.
 */
declare const Autocomplete: ForwardRefExoticComponent<AutocompleteProps<any>>;
export default Autocomplete;
