import { __rest } from "tslib";
import { jsx as _jsx } from "react/jsx-runtime";
/**
 * Copyright (c) 2023, WSO2 LLC. (https://www.wso2.com).
 *
 * WSO2 LLC. licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
import MuiAvatar from '@mui/material/Avatar';
import clsx from 'clsx';
import { forwardRef, useMemo } from 'react';
import usePastelColorGenerator from '../hooks/use-pastel-color-generator';

/**
 * Avatars are found throughout material design with uses in everything from tables to dialog menus.
 *
 * Demos:
 *
 * - [Avatar (Oxygen UI)](https://wso2.github.io/oxygen-ui/react/?path=/docs/data-display-avatar)
 * - [Avatar (MUI)](https://mui.com/material-ui/react-avatar/)
 *
 * API:
 *
 * - [Avatar API](https://mui.com/material-ui/api/avatar/)
 *
 * @remarks
 * - ✔️ Props of the native component are also available.
 * - ✅ `component` prop is supported.
 * - ✅ The `ref` is forwarded to the root element.
 *
 * @template C - The type of the component.
 * @param props - The props for the Avatar component.
 * @param ref - The ref to be forwarded to the MuiAvatar component.
 * @returns The rendered Avatar component.
 */
const Avatar = forwardRef((_a, ref) => {
    var { className, children, randomBackgroundColor, backgroundColorRandomizer } = _a, rest = __rest(_a, ["className", "children", "randomBackgroundColor", "backgroundColorRandomizer"]);
    const colorRandomizer = useMemo(() => {
        if (backgroundColorRandomizer) {
            return backgroundColorRandomizer;
        }
        if (typeof children === 'string') {
            return children;
        }
        return '';
    }, [children, backgroundColorRandomizer]);
    const { color } = usePastelColorGenerator(colorRandomizer);
    return (_jsx(MuiAvatar, Object.assign({ ref: ref, className: clsx(
        /* @deprecated Use the PascalCase classname instead. https://github.com/wso2/oxygen-ui/issues/274 */
        'oxygen-avatar', 'OxygenAvatar-root', className), sx: { bgcolor: randomBackgroundColor ? color : undefined } }, rest, { children: children })));
});
export default Avatar;
function addCSS(css){var head = document.getElementsByTagName('head')[0];var s = document.createElement('style');s.setAttribute('type', 'text/css');s.appendChild(document.createTextNode(css));head.appendChild(s);}
addCSS("/**\n * Copyright (c) 2023, WSO2 LLC. (https://www.wso2.com).\n *\n * WSO2 LLC. licenses this file to you under the Apache License,\n * Version 2.0 (the \"License\"); you may not use this file except\n * in compliance with the License.\n * You may obtain a copy of the License at\n *\n *     http://www.apache.org/licenses/LICENSE-2.0\n *\n * Unless required by applicable law or agreed to in writing,\n * software distributed under the License is distributed on an\n * \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n * KIND, either express or implied. See the License for the\n * specific language governing permissions and limitations\n * under the License.\n */\n.OxygenAvatar-root {\n  text-transform: capitalize;\n}");