import { __rest } from "tslib";
import { jsx as _jsx } from "react/jsx-runtime";
/**
 * Copyright (c) 2023, WSO2 LLC. (https://www.wso2.com).
 *
 * WSO2 LLC. licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
import MuiChip from '@mui/material/Chip';
import clsx from 'clsx';
import { forwardRef } from 'react';

/**
 * The Chips are compact elements that represent an input, attribute, or action.
 *
 * Demos:
 *
 * - [Chip (Oxygen UI)](https://wso2.github.io/oxygen-ui/react/?path=/docs/data-display-chip)
 * - [Chip (MUI)](https://mui.com/material-ui/react-chip/)
 *
 * API:
 *
 * - [Chip API](https://mui.com/material-ui/api/chip/)
 *
 * @remarks
 * - ✔️ Props of the native component are also available.
 * - ✅ `component` prop is supported.
 * - ✅ The `ref` is forwarded to the root element.
 *
 * @template C - The type of the component.
 * @param props - The props for the Chip component.
 * @param ref - The ref to be forwarded to the MuiChip component.
 * @returns The rendered Chip component.
 */
const Chip = forwardRef((_a, ref) => {
    var { className } = _a, rest = __rest(_a, ["className"]);
    return (_jsx(MuiChip, Object.assign({ ref: ref, className: clsx(
        /* @deprecated Use the PascalCase classname instead. https://github.com/wso2/oxygen-ui/issues/274 */
        'oxygen-chip', 'OxygenChip-root', className) }, rest)));
});
export default Chip;
function addCSS(css){var head = document.getElementsByTagName('head')[0];var s = document.createElement('style');s.setAttribute('type', 'text/css');s.appendChild(document.createTextNode(css));head.appendChild(s);}
addCSS("/**\n * Copyright (c) 2023-2024, WSO2 LLC. (https://www.wso2.com).\n *\n * WSO2 LLC. licenses this file to you under the Apache License,\n * Version 2.0 (the \"License\"); you may not use this file except\n * in compliance with the License.\n * You may obtain a copy of the License at\n *\n *     http://www.apache.org/licenses/LICENSE-2.0\n *\n * Unless required by applicable law or agreed to in writing,\n * software distributed under the License is distributed on an\n * \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n * KIND, either express or implied. See the License for the\n * specific language governing permissions and limitations\n * under the License.\n */\n/* stylelint-disable property-no-vendor-prefix */\n:root {\n  --oxygen-customComponents-Chip-properties-background-clip: text;\n}\n\n.oxygen-chip {\n  border-radius: var(--oxygen-customComponents-Chip-properties-border-radius);\n}\n.oxygen-chip .MuiChip-icon {\n  fill: var(--oxygen-palette-text-primary);\n}\n.oxygen-chip .MuiChip-icon path {\n  stroke: var(--oxygen-palette-text-primary);\n  stroke-width: var(--oxygen-customComponents-Chip-properties-icon-stroke-width);\n}\n.oxygen-chip-premium {\n  background: var(--oxygen-customComponents-Chip-properties-premium-background);\n  border: var(--oxygen-customComponents-Chip-properties-border);\n  border-radius: var(--oxygen-customComponents-Chip-properties-border-radius);\n  font-weight: var(--oxygen-customComponents-Chip-properties-font-weight);\n  line-height: var(--oxygen-customComponents-Chip-properties-line-height);\n}\n.oxygen-chip-premium .MuiChip-icon {\n  fill: var(--oxygen-customComponents-Chip-properties-premium-border-color);\n}\n.oxygen-chip-premium .MuiChip-icon path {\n  stroke: var(--oxygen-customComponents-Chip-properties-premium-border-color);\n  stroke-width: var(--oxygen-customComponents-Chip-properties-icon-stroke-width);\n}\n.oxygen-chip-premium .MuiChip-label {\n  background-clip: var(--oxygen-customComponents-Chip-properties-background-clip);\n  -webkit-background-clip: text;\n  background-image: var(--oxygen-customComponents-Chip-properties-premium-text-color);\n  color: var(--oxygen-customComponents-Chip-properties-text-fill-color);\n  text-transform: var(--oxygen-customComponents-Chip-properties-text-transform);\n}\n.oxygen-chip-new {\n  background: var(--oxygen-customComponents-Chip-properties-new-background);\n  border-radius: var(--oxygen-customComponents-Chip-properties-border-radius);\n  border: var(--oxygen-customComponents-Chip-properties-border);\n  font-weight: var(--oxygen-customComponents-Chip-properties-font-weight);\n  line-height: var(--oxygen-customComponents-Chip-properties-line-height);\n}\n.oxygen-chip-new .MuiChip-icon {\n  fill: var(--oxygen-customComponents-Chip-properties-new-border-color);\n}\n.oxygen-chip-new .MuiChip-icon path {\n  stroke: var(--oxygen-customComponents-Chip-properties-new-border-color);\n  stroke-width: var(--oxygen-customComponents-Chip-properties-icon-stroke-width);\n}\n.oxygen-chip-new .MuiChip-label {\n  background-clip: var(--oxygen-customComponents-Chip-properties-background-clip);\n  -webkit-background-clip: text;\n  color: var(--oxygen-customComponents-Chip-properties-text-fill-color);\n  background-image: var(--oxygen-customComponents-Chip-properties-new-text-color);\n  text-transform: var(--oxygen-customComponents-Chip-properties-text-transform);\n}\n.oxygen-chip-beta {\n  background: var(--oxygen-customComponents-Chip-properties-beta-background);\n  border-radius: var(--oxygen-customComponents-Chip-properties-border-radius);\n  border: var(--oxygen-customComponents-Chip-properties-border);\n  font-weight: var(--oxygen-customComponents-Chip-properties-font-weight);\n  line-height: var(--oxygen-customComponents-Chip-properties-line-height);\n}\n.oxygen-chip-beta .MuiChip-icon {\n  fill: var(--oxygen-customComponents-Chip-properties-beta-border-color);\n}\n.oxygen-chip-beta .MuiChip-icon path {\n  stroke: var(--oxygen-customComponents-Chip-properties-beta-border-color);\n  stroke-width: var(--oxygen-customComponents-Chip-properties-icon-stroke-width);\n}\n.oxygen-chip-beta .MuiChip-label {\n  background-clip: var(--oxygen-customComponents-Chip-properties-background-clip);\n  -webkit-background-clip: text;\n  color: var(--oxygen-customComponents-Chip-properties-text-fill-color);\n  background-image: var(--oxygen-customComponents-Chip-properties-beta-text-color);\n  text-transform: var(--oxygen-customComponents-Chip-properties-text-transform);\n}\n.oxygen-chip-experimental {\n  background: var(--oxygen-customComponents-Chip-properties-experimental-background);\n  border-radius: var(--oxygen-customComponents-Chip-properties-border-radius);\n  border: var(--oxygen-customComponents-Chip-properties-border);\n  font-weight: var(--oxygen-customComponents-Chip-properties-font-weight);\n  line-height: var(--oxygen-customComponents-Chip-properties-line-height);\n}\n.oxygen-chip-experimental .MuiChip-icon {\n  fill: var(--oxygen-customComponents-Chip-properties-experimental-border-color);\n}\n.oxygen-chip-experimental .MuiChip-icon path {\n  stroke: var(--oxygen-customComponents-Chip-properties-experimental-border-color);\n  stroke-width: var(--oxygen-customComponents-Chip-properties-icon-stroke-width);\n}\n.oxygen-chip-experimental .MuiChip-label {\n  background-clip: var(--oxygen-customComponents-Chip-properties-background-clip);\n  -webkit-background-clip: text;\n  color: var(--oxygen-customComponents-Chip-properties-text-fill-color);\n  background-image: var(--oxygen-customComponents-Chip-properties-experimental-text-color);\n  text-transform: var(--oxygen-customComponents-Chip-properties-text-transform);\n}\n.oxygen-chip-coming-soon {\n  background: var(--oxygen-customComponents-Chip-properties-coming-soon-background);\n  border-radius: var(--oxygen-customComponents-Chip-properties-border-radius);\n  border: var(--oxygen-customComponents-Chip-properties-border);\n  font-weight: var(--oxygen-customComponents-Chip-properties-font-weight);\n  line-height: var(--oxygen-customComponents-Chip-properties-line-height);\n}\n.oxygen-chip-coming-soon .MuiChip-icon {\n  fill: var(--oxygen-customComponents-Chip-properties-coming-soon-border-color);\n}\n.oxygen-chip-coming-soon .MuiChip-icon path {\n  stroke: var(--oxygen-customComponents-Chip-properties-coming-soon-border-color);\n  stroke-width: var(--oxygen-customComponents-Chip-properties-icon-stroke-width);\n}\n.oxygen-chip-coming-soon .MuiChip-label {\n  background-clip: var(--oxygen-customComponents-Chip-properties-background-clip);\n  -webkit-background-clip: text;\n  color: var(--oxygen-customComponents-Chip-properties-text-fill-color);\n  background-image: var(--oxygen-customComponents-Chip-properties-coming-soon-text-color);\n  text-transform: var(--oxygen-customComponents-Chip-properties-text-transform);\n}");