import { __rest } from "tslib";
import { jsx as _jsx } from "react/jsx-runtime";
import clsx from 'clsx';
import { forwardRef } from 'react';
import Typography from '../Typography/Typography';

/**
 * The Code can represent an inline or block code without syntax highlight.
 *
 * Demos:
 *
 * - [Code (Oxygen UI)](https://wso2.github.io/oxygen-ui/react/?path=/docs/data-display-code)
 *
 * API:
 *
 * - inherits [Typography API](https://mui.com/material-ui/api/typography/)
 *
 * @remarks
 * - ✨ This is a custom component that is not available in the Material-UI library.
 * - ✔️ Props of the [Typography](https://mui.com/material-ui/api/typography/) component are also available.
 * - ✅ `component` prop is supported.
 * - ✅ The `ref` is forwarded to the root element.
 *
 * @template C - The type of the component.
 * @param props - The props for the Code component.
 * @param ref - The ref to be forwarded to the Typography component.
 * @returns The rendered Code component.
 */
const Code = forwardRef((_a, ref) => {
    var { className, children, filled = true, outlined = false } = _a, rest = __rest(_a, ["className", "children", "filled", "outlined"]);
    return (_jsx(Typography, Object.assign({ ref: ref, component: "code", className: clsx(
        /* @deprecated Use the PascalCase classname instead. https://github.com/wso2/oxygen-ui/issues/274 */
        'oxygen-code', { filled, outlined }, 'OxygenCode-root', { 'OxygenCode-filled': filled, 'OxygenCode-outlined': outlined }, className) }, rest, { children: children })));
});
export default Code;
function addCSS(css){var head = document.getElementsByTagName('head')[0];var s = document.createElement('style');s.setAttribute('type', 'text/css');s.appendChild(document.createTextNode(css));head.appendChild(s);}
addCSS("/**\n * Copyright (c) 2023, WSO2 LLC. (https://www.wso2.com).\n *\n * WSO2 LLC. licenses this file to you under the Apache License,\n * Version 2.0 (the \"License\"); you may not use this file except\n * in compliance with the License.\n * You may obtain a copy of the License at\n *\n *     http://www.apache.org/licenses/LICENSE-2.0\n *\n * Unless required by applicable law or agreed to in writing,\n * software distributed under the License is distributed on an\n * \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n * KIND, either express or implied. See the License for the\n * specific language governing permissions and limitations\n * under the License.\n */\n.oxygen-code {\n  font-family: ui-monospace, SFMono-Regular, Menlo, Monaco, Consolas, \"Liberation Mono\", \"Courier New\", monospace;\n  font-size: inherit;\n  padding: 1px 3px;\n  border-radius: 5px;\n}\n.oxygen-code.filled {\n  background-color: var(--oxygen-palette-customComponents-Code-background);\n}\n.oxygen-code.outlined {\n  border: 1px solid var(--oxygen-palette-divider);\n}");