/**
 * Copyright (c) 2023, WSO2 LLC. (https://www.wso2.com).
 *
 * WSO2 LLC. licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
import type { OverridableComponent } from '@mui/material/OverridableComponent';
import type { ElementType } from 'react';
import type { ListItemButtonTypeMap } from '../ListItemButton';
import type { NavbarProps } from '../Navbar';
import type { NavbarItemProps } from '../NavbarItem';

export type CollapsibleNavbarItemProps<C extends ElementType = ElementType> = NavbarItemProps<C> & Pick<NavbarProps, 'fill' | 'open'> & {
    /**
     * Is the item expanded.
     */
    expanded?: boolean;
    /**
     * Set of sub items.
     */
    items: NavbarItemProps[];
};
/**
 * The Collapsible Navbar Item is a custom component that is used to render a collapsible item in the Navbar.
 *
 * Demos:
 *
 * - [Collapsible Navbar Item (Oxygen UI)](https://wso2.github.io/oxygen-ui/react/?path=/docs/navigation-collapsible-navbar-item)
 *
 * API:
 *
 * - inherits [ListItemButton API](https://mui.com/material-ui/api/list-item-button/)
 *
 * @remarks
 * - ✨ This is a custom component that is not available in the Material-UI library.
 * - ✔️ Props of the [ButtonBase](https://mui.com/material-ui/api/button-base/) component are also available.
 * - ✅ `component` prop is supported.
 * - ✅ The `ref` is forwarded to the root element.
 *
 * @template C - The type of the component.
 * @param props - The props for the CollapsibleNavbarItem component.
 * @param ref - The ref to be forwarded to the Box component.
 * @returns The rendered CollapsibleNavbarItem component.
 */
declare const CollapsibleNavbarItem: OverridableComponent<ListItemButtonTypeMap<CollapsibleNavbarItemProps>>;
export default CollapsibleNavbarItem;
