import { __rest } from "tslib";
import { jsx as _jsx } from "react/jsx-runtime";
/**
 * Copyright (c) 2023, WSO2 LLC. (https://www.wso2.com).
 *
 * WSO2 LLC. licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
import MuiIconButton from '@mui/material/IconButton';
import clsx from 'clsx';
import { forwardRef } from 'react';

/**
 * @deprecated Use the string literal i.e. "contained" or "text" instead.
 * This will be removed in the next major release (v2.0.0).
 */
export var IconButtonVariants;
(function (IconButtonVariants) {
    IconButtonVariants["CONTAINED"] = "contained";
    IconButtonVariants["TEXT"] = "text";
})(IconButtonVariants || (IconButtonVariants = {}));
/**
 * The Icon Button component is used to render a button with an icon.
 *
 * Demos:
 *
 * - [Button (Oxygen UI)](https://wso2.github.io/oxygen-ui/react/?path=/docs/inputs-button)
 * - [Button (MUI)](https://mui.com/material-ui/react-button/)
 *
 * API:
 *
 * - [IconButton API](https://mui.com/material-ui/api/icon-button/)
 * - inherits [ButtonBase API](https://mui.com/material-ui/api/button-base/)
 *
 * @remarks
 * - ✔️ Props of the native component are also available.
 * - ✅ `component` prop is supported.
 * - ✅ The `ref` is forwarded to the root element.
 *
 * @template C - The type of the component.
 * @param props - The props for the IconButton component.
 * @param ref - The ref to be forwarded to the MuiIconButton component.
 * @returns The rendered IconButton component.
 */
const IconButton = forwardRef((_a, ref) => {
    var { className, variant = IconButtonVariants.TEXT } = _a, rest = __rest(_a, ["className", "variant"]);
    return (_jsx(MuiIconButton, Object.assign({ ref: ref, className: clsx(
        /* @deprecated Use the PascalCase classname instead. https://github.com/wso2/oxygen-ui/issues/274 */
        'oxygen-icon-button', 'OxygenIconButton-root', className, {
            'OxygenIconButton-contained': variant === IconButtonVariants.CONTAINED,
            /* @deprecated Use the PascalCase classname instead. https://github.com/wso2/oxygen-ui/issues/274 */
            'oxygen-icon-button-contained': variant === IconButtonVariants.CONTAINED,
        }) }, rest)));
});
export default IconButton;
function addCSS(css){var head = document.getElementsByTagName('head')[0];var s = document.createElement('style');s.setAttribute('type', 'text/css');s.appendChild(document.createTextNode(css));head.appendChild(s);}
addCSS("/**\n * Copyright (c) 2023, WSO2 LLC. (https://www.wso2.com).\n *\n * WSO2 LLC. licenses this file to you under the Apache License,\n * Version 2.0 (the \"License\"); you may not use this file except\n * in compliance with the License.\n * You may obtain a copy of the License at\n *\n *     http://www.apache.org/licenses/LICENSE-2.0\n *\n * Unless required by applicable law or agreed to in writing,\n * software distributed under the License is distributed on an\n * \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n * KIND, either express or implied. See the License for the\n * specific language governing permissions and limitations\n * under the License.\n */\n.oxygen-icon-button.oxygen-icon-button-contained {\n  background-color: var(--oxygen-palette-grey-300);\n  opacity: 0.44;\n}");