import { __rest } from "tslib";
import { jsx as _jsx } from "react/jsx-runtime";
import MuiPaper from '@mui/material/Paper';
import clsx from 'clsx';
import { forwardRef } from 'react';
/**
 * The Paper component is a container for displaying content on an elevated surface.
 *
 * Demos:
 *
 * - [Card (Oxygen UI)](https://wso2.github.io/oxygen-ui/react/?path=/docs/surfaces-card)
 * - [Card (MUI)](https://mui.com/material-ui/react-card/)
 * - [Paper (Oxygen UI)](https://wso2.github.io/oxygen-ui/react/?path=/docs/surfaces-paper)
 * - [Paper](https://mui.com/material-ui/react-paper/)
 *
 * API:
 *
 * - [Paper API](https://mui.com/material-ui/api/paper/)
 *
 * @remarks
 * - ✔️ Props of the native component are also available.
 * - ✅ `component` prop is supported.
 * - ✅ The `ref` is forwarded to the root element.
 *
 * @template C - The type of the component.
 * @param props - The props for the Paper component.
 * @param ref - The ref to be forwarded to the MuiPaper component.
 * @returns The rendered Paper component.
 */
const Paper = forwardRef((_a, ref) => {
    var { className } = _a, rest = __rest(_a, ["className"]);
    return (_jsx(MuiPaper, Object.assign({ className: clsx(
        /* @deprecated Use the PascalCase classname instead. https://github.com/wso2/oxygen-ui/issues/274 */
        'oxygen-paper', 'OxygenPaper-root', className) }, rest, { ref: ref })));
});
export default Paper;
