import { __rest } from "tslib";
import { jsx as _jsx } from "react/jsx-runtime";
import MuiRadio from '@mui/material/Radio';
import clsx from 'clsx';
import { forwardRef } from 'react';
/**
 * A Radio component is used to allow users to select a single option from a list of options.
 *
 * Demos:
 *
 * - [Radio Group (Oxygen UI)](https://wso2.github.io/oxygen-ui/react/?path=/docs/inputs-radio-group)
 * - [Radio Group (MUI)](https://mui.com/material-ui/react-radio-button/)
 *
 * API:
 *
 * - [Radio API](https://mui.com/material-ui/api/radio/)
 * - inherits [ButtonBase API](https://mui.com/material-ui/api/button-base/)
 *
 * @remarks
 * - ✔️ Props of the [ButtonBase](https://mui.com/material-ui/api/button-base/) component are also available.
 * - ✅ `component` prop is supported.
 * - ✅ The `ref` is forwarded to the root element.
 *
 * @template C - The type of the component.
 * @param props - The props for the Radio component.
 * @param ref - The ref to be forwarded to the MuiRadio component.
 * @returns The rendered Radio component.
 */
const Radio = forwardRef((_a, ref) => {
    var { className } = _a, rest = __rest(_a, ["className"]);
    return (_jsx(MuiRadio, Object.assign({ className: clsx(
        /* @deprecated Use the PascalCase classname instead. https://github.com/wso2/oxygen-ui/issues/274 */
        'oxygen-radio', 'OxygenRadio-root', className) }, rest, { ref: ref })));
});
export default Radio;
