import { __rest } from "tslib";
import { jsx as _jsx, Fragment as _Fragment, jsxs as _jsxs } from "react/jsx-runtime";
/**
 * Copyright (c) 2023, WSO2 LLC. (https://www.wso2.com).
 *
 * WSO2 LLC. licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
import MuiSelect from '@mui/material/Select';
import clsx from 'clsx';
import { forwardRef } from 'react';
import InputLabel from '../InputLabel';

/**
 * The Select components are used for collecting user provided information from a list of options.
 *
 * Demos:
 *
 * - [Select (Oxygen UI)](https://mui.com/material-ui/react-select/)
 * - [Select (MUI)](https://mui.com/material-ui/react-select/)
 *
 * API:
 *
 * - [Select API](https://mui.com/material-ui/api/select/)
 * - inherits [OutlinedInput API](https://mui.com/material-ui/api/outlined-input/)
 *
 * @remarks
 * - ✔️ Props of the [OutlinedInput](https://mui.com/material-ui/api/outlined-input/) component are also available.
 * - ❌ `component` prop is not supported.
 * - ✅ The `ref` is forwarded to the root element.
 *
 * @param props - The props for the Select component.
 * @param ref - The ref to be forwarded to the MuiSelect component.
 * @returns The rendered Select component.
 */
const Select = forwardRef((_a, ref) => {
    var { className, InputLabelProps = {
        disableAnimation: true,
        focused: false,
        shrink: false,
    }, label, name, required } = _a, rest = __rest(_a, ["className", "InputLabelProps", "label", "name", "required"]);
    const labelProps = Object.assign({
        disableAnimation: true,
        focused: false,
        required,
        shrink: false,
    }, InputLabelProps);
    return (_jsxs(_Fragment, { children: [label && (_jsx(InputLabel, Object.assign({ id: name, htmlFor: name }, labelProps, { className: clsx('oxygen-select-static-label', InputLabelProps === null || InputLabelProps === void 0 ? void 0 : InputLabelProps.className) }, { children: label }))), _jsx(MuiSelect, Object.assign({ ref: ref, labelId: name, className: clsx(
                /* @deprecated Use the PascalCase classname instead. https://github.com/wso2/oxygen-ui/issues/274 */
                'oxygen-select', 'OxygenSelect-root', className) }, rest))] }));
});
export default Select;
function addCSS(css){var head = document.getElementsByTagName('head')[0];var s = document.createElement('style');s.setAttribute('type', 'text/css');s.appendChild(document.createTextNode(css));head.appendChild(s);}
addCSS("/**\n * Copyright (c) 2023, WSO2 LLC. (https://www.wso2.com).\n *\n * WSO2 LLC. licenses this file to you under the Apache License,\n * Version 2.0 (the \"License\"); you may not use this file except\n * in compliance with the License.\n * You may obtain a copy of the License at\n *\n *     http://www.apache.org/licenses/LICENSE-2.0\n *\n * Unless required by applicable law or agreed to in writing,\n * software distributed under the License is distributed on an\n * \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\n * KIND, either express or implied. See the License for the\n * specific language governing permissions and limitations\n * under the License.\n */\n.oxygen-select-static-label {\n  margin-top: -40px;\n  margin-left: -14px;\n}");