import { __rest } from "tslib";
import { jsx as _jsx } from "react/jsx-runtime";
import MuiStepper from '@mui/material/Stepper';
import clsx from 'clsx';
import { forwardRef } from 'react';
/**
 * The Stepper component is used to display a series of steps in a defined sequence.
 *
 * Demos:
 *
 * - [Stepper (Oxygen UI)](https://wso2.github.io/oxygen-ui/react/?path=/docs/navigation-stepper)
 * - [Stepper (MUI)](https://mui.com/material-ui/react-stepper/)
 *
 * API:
 *
 * - [Stepper API](https://mui.com/material-ui/api/stepper/)
 *
 * @remarks
 * - ✔️ Props of the native component are also available.
 * - ✅ `component` prop is supported.
 * - ✅ The `ref` is forwarded to the root element.
 *
 * @template C - The type of the component.
 * @param props - The props for the Stepper component.
 * @param ref - The ref to be forwarded to the MuiStepper component.
 * @returns The rendered Stepper component.
 */
const Stepper = forwardRef((_a, ref) => {
    var { className } = _a, rest = __rest(_a, ["className"]);
    return (_jsx(MuiStepper, Object.assign({ className: clsx(
        /* @deprecated Use the PascalCase classname instead. https://github.com/wso2/oxygen-ui/issues/274 */
        'oxygen-stepper', 'OxygenStepper-root', className), ref: ref }, rest)));
});
export default Stepper;
