import { __rest } from "tslib";
import { jsx as _jsx } from "react/jsx-runtime";
/**
 * Copyright (c) 2024, WSO2 LLC. (https://www.wso2.com).
 *
 * WSO2 LLC. licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
import { styled } from '@mui/material/styles';
import MuiTableRow from '@mui/material/TableRow';
import clsx from 'clsx';
import { forwardRef } from 'react';
const TableRowWithoutBorder = styled(MuiTableRow)(() => ({
    'td, th': {
        border: 0,
    },
}));
/**
 * The TableRow component lets display a row of data
 *
 *
 * API:
 * - [TableRow API](https://mui.com/material-ui/api/table-row/)
 *
 * @remarks
 * - ✅ `component` prop is supported.
 * - ✅ The `ref` is forwarded to the root element.
 *
 * @template C - The type of the component.
 * @param props - The props for the Table component.
 * @param ref - The ref to be forwarded to the MuiTable component.
 * @returns The rendered Tablee component.
 */
const TableRow = forwardRef((_a, ref) => {
    var { className, hideBorder } = _a, rest = __rest(_a, ["className", "hideBorder"]);
    if (hideBorder) {
        return (_jsx(TableRowWithoutBorder, Object.assign({ ref: ref, className: clsx(
            /* @deprecated Use the PascalCase classname instead. https://github.com/wso2/oxygen-ui/issues/274 */
            'oxygen-table-row', 'OxygenTableRow-root', className) }, rest)));
    }
    return (_jsx(MuiTableRow, Object.assign({ ref: ref, className: clsx(
        /* @deprecated Use the PascalCase classname instead. https://github.com/wso2/oxygen-ui/issues/274 */
        'oxygen-table-row', 'OxygenTableRow-root', className) }, rest)));
});
export default TableRow;
