/**
 * Copyright (c) 2023, WSO2 LLC. (https://www.wso2.com).
 *
 * WSO2 LLC. licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
import { FormControlTypeMap } from '@mui/material/FormControl';
import type { OverridableComponent } from '@mui/material/OverridableComponent';
import type { TextFieldProps as MuiTextFieldProps } from '@mui/material/TextField';
import type { ElementType } from 'react';

/**
 * @deprecated Use the string literal i.e. "password" or "text" instead.
 * This will be removed in the next major release (v2.0.0).
 */
export declare enum TextFieldInputTypes {
    INPUT_PASSWORD = "password",
    INPUT_TEXT = "text"
}
export type TextFieldProps<C extends ElementType = ElementType> = {
    /**
     * The component used for the root node. Either a string to use a HTML element or a component.
     */
    component?: C;
    /**
     * Criteria for user input.
     */
    criteria?: string[];
} & Omit<MuiTextFieldProps, 'component'>;
/**
 * The Text Fields let users enter and edit text..
 *
 * Demos:
 *
 * - [Autocomplete (Oxygen UI)](https://wso2.github.io/oxygen-ui/react/?path=/docs/inputs-autocomplete)
 * - [Autocomplete (MUI)](https://mui.com/material-ui/react-autocomplete/)
 * - [Text Field (Oxygen UI)](https://wso2.github.io/oxygen-ui/react/?path=/docs/inputs-text-field)
 * - [Text Field (MUI)](https://mui.com/material-ui/react-text-field/)
 *
 * API:
 *
 * - [TextField API](https://mui.com/material-ui/api/text-field/)
 * - inherits [FormControl API](https://mui.com/material-ui/api/form-control/)
 *
 * @remarks
 * - ✔️ Props of the [FormControl](https://mui.com/material-ui/api/form-control/) component are also available.
 * - ✅ `component` prop is supported.
 * - ✅ The `ref` is forwarded to the root element.
 *
 * @template C - The type of the component.
 * @param props - The props for the TextField component.
 * @param ref - The ref to be forwarded to the MuiTextField component.
 * @returns The rendered TextField component.
 */
declare const TextField: OverridableComponent<FormControlTypeMap<TextFieldProps>>;
export default TextField;
