import { __rest } from "tslib";
import { jsx as _jsx } from "react/jsx-runtime";
import MuiToolbar from '@mui/material/Toolbar';
import clsx from 'clsx';
import { forwardRef } from 'react';
/**
 * The Toolbar component is a container for grouping elements such as AppBar.
 *
 * Demos:
 *
 * - [App Bar (Oxygen UI)](https://wso2.github.io/oxygen-ui/react/?path=/docs/surfaces-app-bar)
 * - [App Bar (MUI)](https://mui.com/material-ui/react-app-bar/)
 *
 * API:
 *
 * - [Toolbar API](https://mui.com/material-ui/api/toolbar/)
 *
 * @remarks
 * - ✔️ Props of the native component are also available.
 * - ✅ `component` prop is supported.
 * - ✅ The `ref` is forwarded to the root element.
 *
 * @template C - The type of the component.
 * @param props - The props for the Skeleton component.
 * @param ref - The ref to be forwarded to the MuiSkeleton component.
 * @returns The rendered Skeleton component.
 */
const Toolbar = forwardRef((_a, ref) => {
    var { className } = _a, rest = __rest(_a, ["className"]);
    return (_jsx(MuiToolbar, Object.assign({ ref: ref, className: clsx(
        /* @deprecated Use the PascalCase classname instead. https://github.com/wso2/oxygen-ui/issues/274 */
        'oxygen-toolbar', 'OxygenToolbar-root', className) }, rest)));
});
export default Toolbar;
