import { __rest } from "tslib";
import { jsx as _jsx } from "react/jsx-runtime";
import MuiTypography from '@mui/material/Typography';
import clsx from 'clsx';
import { forwardRef } from 'react';
/**
 * The Typography can present your design and content as clearly and efficiently as possible.
 *
 * Demos:
 *
 * - [Breadcrumbs (Oxygen UI)](https://wso2.github.io/oxygen-ui/react/?path=/docs/navigation-breadcrumbs)
 * - [Breadcrumbs (MUI)](https://mui.com/material-ui/react-breadcrumbs/)
 * - [Typography (Oxygen UI)](https://wso2.github.io/oxygen-ui/react/?path=/docs/data-display-typography)
 * - [Typography (MUI)](https://mui.com/material-ui/react-typography/)
 *
 * API:
 *
 * - [Typography API](https://mui.com/material-ui/api/typography/)
 *
 * @remarks
 * - ✔️ Props of the native component are also available.
 * - ✅ `component` prop is supported.
 * - ✅ The `ref` is forwarded to the root element.
 *
 * @template C - The type of the component.
 * @param props - The props for the Typography component.
 * @param ref - The ref to be forwarded to the MuiTypography component.
 * @returns The rendered Typography component.
 */
const Typography = forwardRef((_a, ref) => {
    var { className } = _a, rest = __rest(_a, ["className"]);
    return (_jsx(MuiTypography, Object.assign({ ref: ref, className: clsx(
        /* @deprecated Use the PascalCase classname instead. https://github.com/wso2/oxygen-ui/issues/274 */
        'oxygen-typography', 'OxygenTypography-root', className) }, rest)));
});
export default Typography;
