/**
 * Copyright (c) 2024, WSO2 LLC. (https://www.wso2.com).
 *
 * WSO2 LLC. licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
import type { OverridableComponent } from '@mui/material/OverridableComponent';
import type { ElementType, ReactElement } from 'react';
import type { BoxProps, BoxTypeMap } from '../Box';
import './transition-stepper.scss';
export type TransitionStepperProps<C extends ElementType = ElementType> = BoxProps<C> & {
    /**
     * Animate the slide transition.
     */
    animateOnSlide?: boolean;
    /**
     * Current step.
     */
    currentStep: number;
    /**
     * Steps to be rendered.
     */
    steps: ReactElement[];
};
/**
 * The TransitionStepper can be used to compose wizards and carousels.
 *
 * Demos:
 *
 * - [Stepper (Oxygen UI)](https://wso2.github.io/oxygen-ui/react/?path=/docs/surfaces-stepper--overview)
 *
 * API:
 *
 * - inherits [Box API](https://mui.com/material-ui/api/box/)
 *
 * @remarks
 * - ✨ This is a custom component that is not available in the Material-UI library.
 * - ✔️ Props of the [Box](https://mui.com/material-ui/api/box/) component are also available.
 * - ✅ `component` prop is supported.
 * - ✅ The `ref` is forwarded to the root element.
 *
 * @template C - The type of the component.
 * @param props - The props for the TransitionStepper component.
 * @param ref - The ref to be forwarded to the Box component.
 * @returns The rendered TransitionStepper component.
 */
declare const TransitionStepper: OverridableComponent<BoxTypeMap<TransitionStepperProps>>;
export default TransitionStepper;
