/**
 * Copyright (c) 2023, WSO2 LLC. (https://www.wso2.com).
 *
 * WSO2 LLC. licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
import type { OverridableComponent } from '@mui/material/OverridableComponent';
import type { ElementType, ReactNode } from 'react';
import type { ListItemButtonProps, ListItemButtonTypeMap } from '../ListItemButton';
import type { NavbarProps } from '../Navbar';
import './navbar-item.scss';
export type NavbarItemProps<C extends ElementType = ElementType> = ListItemButtonProps<C> & Pick<NavbarProps, 'fill' | 'open'> & {
    /**
     * Icon for the Navbar item.
     * @example <HomeIcon />
     */
    icon?: ReactNode;
    /**
     * Unique id for the item.
     */
    id?: string;
    /**
     * Label to display on the UI.
     * @example Overview
     */
    label: ReactNode;
    /**
     * Tag to display on the UI.
     * @example Beta
     */
    tag?: string;
    /**
     * Tag color variant.
     */
    tagClassName?: 'premium' | 'beta' | 'new' | 'experimental';
};
/**
 * The Navbar Item component is used to represent an item in the Navbar.
 *
 * Demos:
 *
 * - [Navbar Item (Oxygen UI)](https://wso2.github.io/oxygen-ui/react/?path=/docs/navigation-navbar-item)
 *
 * API:
 *
 * - inherits [ListItemButton API](https://mui.com/material-ui/api/list-item-button/)
 *
 * @remarks
 * - ✨ This is a custom component that is not available in the Material-UI library.
 * - ✔️ Props of the [ListItemButton](https://mui.com/material-ui/api/list-item-button/) component are also available.
 * - ✅ `component` prop is supported.
 * - ✅ The `ref` is forwarded to the root element.
 *
 * @template C - The type of the component.
 * @param props - The props for the NavbarItem component.
 * @param ref - The ref to be forwarded to the Box component.
 * @returns The rendered NavbarItem component.
 */
declare const NavbarItem: OverridableComponent<ListItemButtonTypeMap<NavbarItemProps>>;
export default NavbarItem;
